@@ -71,15 +71,15 @@
     <message>
         <location filename="../tweak.ui" line="39"/>
         <location filename="../tweak.ui" line="233"/>
-        <location filename="../tweak.ui" line="508"/>
-        <location filename="../tweak.ui" line="587"/>
-        <location filename="../tweak.ui" line="643"/>
-        <location filename="../tweak.ui" line="670"/>
-        <location filename="../tweak.ui" line="862"/>
-        <location filename="../tweak.ui" line="1253"/>
-        <location filename="../tweak.ui" line="1382"/>
-        <location filename="../tweak.ui" line="1429"/>
-        <location filename="../tweak.ui" line="1679"/>
+        <location filename="../tweak.ui" line="520"/>
+        <location filename="../tweak.ui" line="599"/>
+        <location filename="../tweak.ui" line="655"/>
+        <location filename="../tweak.ui" line="682"/>
+        <location filename="../tweak.ui" line="874"/>
+        <location filename="../tweak.ui" line="1265"/>
+        <location filename="../tweak.ui" line="1394"/>
+        <location filename="../tweak.ui" line="1441"/>
+        <location filename="../tweak.ui" line="1532"/>
         <source>Apply</source>
         <extracomment>apply changes</extracomment>
         <translation>Hyväksy</translation>
@@ -116,9 +116,9 @@
     </message>
     <message>
         <location filename="../tweak.ui" line="101"/>
-        <location filename="../tweak.ui" line="1036"/>
-        <location filename="../tweak.ui" line="1146"/>
-        <location filename="../tweak.ui" line="1273"/>
+        <location filename="../tweak.ui" line="1048"/>
+        <location filename="../tweak.ui" line="1158"/>
+        <location filename="../tweak.ui" line="1285"/>
         <source>Placement</source>
         <translation>Sijoitus</translation>
     </message>
@@ -186,663 +186,673 @@
         <translation>Sovellus</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="295"/>
+        <location filename="../tweak.ui" line="301"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Toggle Dark Mode for GTK4 libadwaita applications&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Vaihda tumma tila GTK4 libadwaita sovelluksille&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="298"/>
+        <location filename="../tweak.ui" line="304"/>
         <source>Dark Mode</source>
         <translation>Tumma teema</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="305"/>
-        <location filename="../tweak.ui" line="1742"/>
+        <location filename="../tweak.ui" line="311"/>
+        <location filename="../tweak.ui" line="1778"/>
         <source>Window Manager</source>
         <extracomment>theme a window manager border will get</extracomment>
         <translation>Ikkunanhallinta</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="319"/>
+        <location filename="../tweak.ui" line="331"/>
         <source>Legacy Styles</source>
         <translation>Perinteiset tyylit</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="332"/>
+        <location filename="../tweak.ui" line="344"/>
         <source>Icons</source>
         <extracomment>icon theme</extracomment>
         <translation>Kuvakkeet</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="339"/>
+        <location filename="../tweak.ui" line="351"/>
         <source>Cursors</source>
         <extracomment>cursor theme</extracomment>
         <translation>Osoittimet</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="346"/>
+        <location filename="../tweak.ui" line="358"/>
         <source>Save Current Settings as a Theme Set</source>
         <extracomment>save theme settings as a group</extracomment>
         <translation>Tallenna nykyiset asetukset teemana</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="356"/>
+        <location filename="../tweak.ui" line="368"/>
         <source>Size</source>
         <extracomment>size of the cursor</extracomment>
         <translation>Koko</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="366"/>
+        <location filename="../tweak.ui" line="378"/>
         <source>default</source>
         <extracomment>default cursor size determined by X server</extracomment>
         <translation>oletus</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="389"/>
-        <location filename="../tweak.ui" line="441"/>
+        <location filename="../tweak.ui" line="401"/>
+        <location filename="../tweak.ui" line="453"/>
         <source>Compositor</source>
         <translation>Renderöinti</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="401"/>
+        <location filename="../tweak.ui" line="413"/>
         <source>Changing the VBlank mode may help alleviate some screen tearing issues. See Help for more information.</source>
         <translation>Vaihtamalla VBlank-tilan se voi lievittää joitakin ongelmia näytön repeytymisessä. Katso tietoja ohjeesta.</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="404"/>
+        <location filename="../tweak.ui" line="416"/>
         <source>VBlank</source>
         <translation>VBlank</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="412"/>
+        <location filename="../tweak.ui" line="424"/>
         <source>auto</source>
         <translation>automaattinen</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="417"/>
+        <location filename="../tweak.ui" line="429"/>
         <source>glx</source>
         <translation>glx</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="422"/>
+        <location filename="../tweak.ui" line="434"/>
         <source>xpresent</source>
         <translation>xpresent</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="427"/>
-        <location filename="../tweak.ui" line="1010"/>
+        <location filename="../tweak.ui" line="439"/>
+        <location filename="../tweak.ui" line="1022"/>
         <source>off</source>
         <extracomment>setting to 0 turns off screensaver screen blank</extracomment>
         <translation>pois</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="435"/>
+        <location filename="../tweak.ui" line="447"/>
         <source>Transparency and shadow options</source>
         <translation>Läpinäkyvyyden ja varjostuksen asetukset</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="451"/>
+        <location filename="../tweak.ui" line="463"/>
         <source>Xfce Compositor Settings</source>
         <translation>Xfce renderöinti asetukset</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="454"/>
+        <location filename="../tweak.ui" line="466"/>
         <source>Xfwm Settings</source>
         <translation>Xfwm:n asetukset</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="464"/>
+        <location filename="../tweak.ui" line="476"/>
         <source>Launch compton-conf configuration tool</source>
         <translation>Käynnistä compton-conf määritystyökalu</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="467"/>
+        <location filename="../tweak.ui" line="479"/>
         <source>Picom settings</source>
         <translation>Picom asetukset</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="478"/>
+        <location filename="../tweak.ui" line="490"/>
         <source>Edit compton.conf directly in text editor</source>
         <translation>Muokkaa compton.conf -tiedostoa suoraan tekstieditorissa</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="481"/>
+        <location filename="../tweak.ui" line="493"/>
         <source>Edit picom.conf</source>
         <translation>Muokkaa picom.conf</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="528"/>
+        <location filename="../tweak.ui" line="540"/>
         <source>Display</source>
         <translation>Näyttö</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="534"/>
+        <location filename="../tweak.ui" line="546"/>
         <source>Display Tweaks</source>
         <translation>Näytön hienosäädöt</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="540"/>
+        <location filename="../tweak.ui" line="552"/>
         <source>Hardware Backlight</source>
         <extracomment>set the hardware backlight on monitors that have them</extracomment>
         <translation>Laitteen taustavalo</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="563"/>
-        <location filename="../tweak.ui" line="694"/>
+        <location filename="../tweak.ui" line="575"/>
+        <location filename="../tweak.ui" line="706"/>
         <source>TextLabel</source>
         <translation>TextLabel</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="570"/>
+        <location filename="../tweak.ui" line="582"/>
         <source>GTK scaling</source>
         <extracomment>gtk scale factor</extracomment>
         <translation>GTK-skaalaus</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="623"/>
+        <location filename="../tweak.ui" line="635"/>
         <source>Choose Display for xrandr tweaks</source>
         <extracomment>choose the display that the xrandr tweaks will be acted upon</extracomment>
         <translation>Valitse näyttö xrandr-virityksille</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="633"/>
+        <location filename="../tweak.ui" line="645"/>
         <source>Resolution</source>
         <translation>Resoluutio-erottelykyky</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="650"/>
+        <location filename="../tweak.ui" line="662"/>
         <source>xrandr Scaling</source>
         <extracomment>xrandr scale factor</extracomment>
         <translation>xrandr-skaalaus</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="677"/>
+        <location filename="../tweak.ui" line="689"/>
         <source>Software (xrandr) Brightness</source>
         <extracomment>adjust brightness (not backlight) via software</extracomment>
         <translation>Ohjelmiston (xrandr) kirkkaus</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="701"/>
+        <location filename="../tweak.ui" line="713"/>
         <source>Saving is per display</source>
         <translation>Tallennus on näyttökohtaista</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="704"/>
+        <location filename="../tweak.ui" line="716"/>
         <source>Save</source>
         <translation>Tallenna</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="728"/>
+        <location filename="../tweak.ui" line="740"/>
         <source>Xfce</source>
         <translation>Xfce</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="734"/>
+        <location filename="../tweak.ui" line="746"/>
         <source>Desktop</source>
         <translation>Työpöytä</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="740"/>
+        <location filename="../tweak.ui" line="752"/>
         <source>Enable single-click on desktop</source>
         <translation>Avaa työpöydän kohteet yhdellä painalluksella</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="747"/>
+        <location filename="../tweak.ui" line="759"/>
         <source>Enable Desktop Zoom </source>
         <translation>Käytä työpöydän suurennusta</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="754"/>
-        <location filename="../tweak.ui" line="1343"/>
+        <location filename="../tweak.ui" line="766"/>
+        <location filename="../tweak.ui" line="1355"/>
         <source>Show windows from all workspaces in panel</source>
         <translation>Näytä ikkunat kaikista työtiloista paneelissa </translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="761"/>
+        <location filename="../tweak.ui" line="773"/>
         <source>Do not shorten file names on the desktop</source>
         <translation>Älä lyhennä työpöydällä olevia tiedostonimiä</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="771"/>
+        <location filename="../tweak.ui" line="783"/>
         <source>Thunar</source>
         <translation>Thunar</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="777"/>
+        <location filename="../tweak.ui" line="789"/>
         <source>Enable single-click in Thunar File Manager</source>
         <translation>Avaa tiedostot yhdellä painalluksella</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="784"/>
+        <location filename="../tweak.ui" line="796"/>
         <source>Reset custom right-click actions to system defaults</source>
         <translation>Palauta hiiren kakkospainike oletuksiin</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="791"/>
+        <location filename="../tweak.ui" line="803"/>
         <source>Thunar windows always open in split view</source>
         <translation>Avaa ohjelma aina jaetussa kahden palstan näkymässä</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="798"/>
+        <location filename="../tweak.ui" line="810"/>
         <source>Thunar split view opens horizontal</source>
         <translation>Avaa jaettu näkymä aina vaakaan</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="808"/>
+        <location filename="../tweak.ui" line="820"/>
         <source>Show percentages in notifcations when available</source>
         <translation>Näytä prosentit ilmoituksissa, kun ne ovat saatavilla</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="815"/>
+        <location filename="../tweak.ui" line="827"/>
         <source>Show GTK File Dialog action buttons at bottom of dialogs</source>
         <translation>Näytä GTK File Dialog painikkeet valintaikkunoiden alareunassa</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="822"/>
+        <location filename="../tweak.ui" line="834"/>
         <source>(also turns off Client Side Decorations for Xfce applications)</source>
         <translation>(poistaa käytöstä koristeet xfce-sovellusksista)</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="832"/>
+        <location filename="../tweak.ui" line="844"/>
         <source>Enable hibernate on Log Out menu </source>
         <translation>Aseta lepotila valittavaksi &quot;Kirjaudu ulos&quot; -valikossa</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="839"/>
+        <location filename="../tweak.ui" line="851"/>
         <source>note: to hibernate, swap needs to be &gt;= RAM</source>
         <translation>Huomaa: lepotilaa varten swap-muistin on oltava &gt;= RAM</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="873"/>
+        <location filename="../tweak.ui" line="885"/>
         <source>Fluxbox</source>
         <translation>Fluxbox</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="879"/>
-        <location filename="../tweak.ui" line="1353"/>
+        <location filename="../tweak.ui" line="891"/>
+        <location filename="../tweak.ui" line="1365"/>
         <source>Reset Defaults</source>
         <translation>Palauta oletuksiin</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="885"/>
+        <location filename="../tweak.ui" line="897"/>
         <source>Reset DefaultDock</source>
         <translation>Nollaa DefaultDock</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="892"/>
+        <location filename="../tweak.ui" line="904"/>
         <source>Reset Fluxbox Menu</source>
         <translation>Nollaa Fluxbox</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="899"/>
+        <location filename="../tweak.ui" line="911"/>
         <source>Reset ALL mx-fluxbox settings</source>
         <translation>Nollaa KAIKKI mx-fluxbox asetukset</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="906"/>
+        <location filename="../tweak.ui" line="918"/>
         <source>Add new default menu items, if any, to existing fluxbox menu.</source>
         <translation>Lisää uusia fluxbox-valikon kohtia, jos sellaisia on olemassa.</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="909"/>
+        <location filename="../tweak.ui" line="921"/>
         <source>Upgrade existing menu entries</source>
         <translation>Päivitä nykyiset valikon merkinnät</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="919"/>
+        <location filename="../tweak.ui" line="931"/>
         <source>Desktop Icons</source>
         <translation>Työpöydän kuvakkeet</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="925"/>
+        <location filename="../tweak.ui" line="937"/>
         <source>Toggle desktop icons</source>
         <translation>Näytä tai piilota työpöydän kuvakkeet</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="933"/>
-        <location filename="../tweak.ui" line="957"/>
+        <location filename="../tweak.ui" line="945"/>
+        <location filename="../tweak.ui" line="969"/>
         <source>On</source>
         <translation>Päällä</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="938"/>
-        <location filename="../tweak.ui" line="962"/>
+        <location filename="../tweak.ui" line="950"/>
+        <location filename="../tweak.ui" line="974"/>
         <source>Off</source>
         <translation>Pois</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="946"/>
+        <location filename="../tweak.ui" line="958"/>
         <source>Toggle icon captions</source>
         <translation>Aseta kuvakkeiden kuvatekstit</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="967"/>
+        <location filename="../tweak.ui" line="979"/>
         <source>On Hover</source>
         <translation>Hiiren leijuessa päälle</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="994"/>
+        <location filename="../tweak.ui" line="1006"/>
         <source>Screensaver</source>
         <translation>Näytönsäästäjä</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1000"/>
+        <location filename="../tweak.ui" line="1012"/>
         <source>Idle time (minutes)</source>
         <extracomment>set the time of inactivity  before screensaver screen blank occurs</extracomment>
         <translation>Odotusaika (minuuttia)</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1023"/>
+        <location filename="../tweak.ui" line="1035"/>
         <source>Toolbar Settings</source>
         <translation>Työkalurivin asetukset</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1029"/>
+        <location filename="../tweak.ui" line="1041"/>
         <source>Height</source>
         <translation>Korkeus</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1110"/>
-        <location filename="../tweak.ui" line="1220"/>
+        <location filename="../tweak.ui" line="1122"/>
+        <location filename="../tweak.ui" line="1232"/>
         <source>Autohide</source>
         <translation>Piilota pois näkyvistä itsestään</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1117"/>
+        <location filename="../tweak.ui" line="1129"/>
         <source>Show Toolbar</source>
         <translation>Näytä työkalurivi</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1124"/>
+        <location filename="../tweak.ui" line="1136"/>
         <source>Width</source>
         <translation>Leveys</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1140"/>
+        <location filename="../tweak.ui" line="1152"/>
         <source>Dock Settings</source>
         <translation>Paneelin asetukset</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1227"/>
+        <location filename="../tweak.ui" line="1239"/>
         <source>Manage Tint2 Panel</source>
         <translation>Hallitse Tint2 paneelia</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1261"/>
+        <location filename="../tweak.ui" line="1273"/>
         <source>Plasma</source>
         <translation>Plasma</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1267"/>
+        <location filename="../tweak.ui" line="1279"/>
         <source>Affects 1st panel</source>
         <translation>Vaikuttaa paneeliin nro.1</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1284"/>
+        <location filename="../tweak.ui" line="1296"/>
         <source>Bottom</source>
         <translation>Alareuna</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1289"/>
+        <location filename="../tweak.ui" line="1301"/>
         <source>Left</source>
         <translation>Vasen reuna</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1294"/>
+        <location filename="../tweak.ui" line="1306"/>
         <source>Top</source>
         <translation>Yläreuna</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1299"/>
+        <location filename="../tweak.ui" line="1311"/>
         <source>Right</source>
         <translation>Oikea reuna</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1323"/>
+        <location filename="../tweak.ui" line="1335"/>
         <source>Workspace</source>
         <translation>Työtila</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1329"/>
+        <location filename="../tweak.ui" line="1341"/>
         <source>Autostart plasma-discover system tray update notification utility</source>
         <extracomment>enable or disable autostartup of plasma-discover updater utility on login</extracomment>
         <translation>Käynnistä autom. plasma-discover ilmoitusalueen päivitysten ilmoitukset</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1336"/>
+        <location filename="../tweak.ui" line="1348"/>
         <source>Enable single-click</source>
         <translation>Käytä avaamista yhdellä painalluksella</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1359"/>
+        <location filename="../tweak.ui" line="1371"/>
         <source>Reset KDE/Plasma defaults</source>
         <translation>Palauta KDE Plasma oletukset</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1393"/>
+        <location filename="../tweak.ui" line="1405"/>
         <source>Super Key</source>
         <extracomment>referring to the meta or Left Super Key</extracomment>
         <translation>Lippu-näppäin</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1399"/>
+        <location filename="../tweak.ui" line="1411"/>
         <source>Also known as the &quot;windows&quot; key</source>
         <translation>Tunnetaan myös &quot;Windows&quot;-näppäimenä</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1402"/>
+        <location filename="../tweak.ui" line="1414"/>
         <source>Command to run with Super (Meta) key</source>
         <extracomment>label for the field to enter the command to use with super key</extracomment>
         <translation>Suoritettava komento Super (Meta) näppäimelle</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1412"/>
+        <location filename="../tweak.ui" line="1424"/>
         <source>xfce-superkey defaults</source>
         <extracomment>indicates that xfce-superkey will select a command by its default logic</extracomment>
         <translation>xfce-superkey oletus</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1419"/>
+        <location filename="../tweak.ui" line="1431"/>
         <source>Choose application</source>
         <extracomment>description of button action to launch file dialog to choose an application</extracomment>
         <translation>Valitse sovellus</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1450"/>
+        <location filename="../tweak.ui" line="1462"/>
         <source>Miscellaneous</source>
         <translation>Sekalaiset</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1456"/>
+        <location filename="../tweak.ui" line="1518"/>
         <source>Reset Lightdm (login screen) to system default theme</source>
         <translation>Palauta Lightdm (kirjautumisikkuna) oletusteemaan</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1463"/>
+        <location filename="../tweak.ui" line="1623"/>
         <source>Enable mounting of internal drives by non-root users</source>
         <translation>Valtuuta sisäisten asemien liittäminen ei-juurikäyttäjille</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1470"/>
+        <location filename="../tweak.ui" line="1616"/>
         <source>Enable kernel sandbox</source>
         <translation>Kytke päälle ytimen sandbox-tila</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1477"/>
+        <location filename="../tweak.ui" line="1566"/>
         <source>requires reboot</source>
         <translation>vaatii käynnistyksen</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1480"/>
+        <location filename="../tweak.ui" line="1569"/>
         <source>Enable Bluetooth adapters on boot</source>
         <translation>Bluetooth käyttöön käynnistyksen yhteydessä</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1487"/>
+        <location filename="../tweak.ui" line="1694"/>
         <source>Enable Bluetooth battery info for connected devices (requires system restart)</source>
         <extracomment>expose battery info for connected bluetooth devices to the operating system via dbus</extracomment>
         <translation>Bluetooth-akun tiedot kytketyille laitteille (vaatii käynnistämisen)</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1494"/>
+        <location filename="../tweak.ui" line="1491"/>
         <source>Early loading of KVM module is new to  kernel 6.12 and conflicts with some non-KVM virtual machine applications, including virtualbox</source>
         <extracomment>early loading is new on 6.12 kernel and conflicts with virtualbox</extracomment>
         <translation>KVM-moduulin varhainen lataaminen on uutta Kernel 6.12. Se on ristiriidassa joidenkin ei KVM-virtuaalikoneiden kanssa, kuten Virtualbox,</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1497"/>
+        <location filename="../tweak.ui" line="1494"/>
         <source>Disable early KVM module load (must be disabled for Virtualbox operation on kernel 6.12 and up)</source>
         <extracomment>disable early loading of KVM module.  necessary for virtualbox to function with kernels 6.12 and up.  actually default behavior on kernels 6.11 and earlier.</extracomment>
         <translation>Poista käytöstä edellinen KVM-moduuli (täytyy poistaa käytöstä Virtualbox kernel 6.12 ja uudemmat)</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1504"/>
+        <location filename="../tweak.ui" line="1630"/>
         <source>Apt installs additional &quot;recommends&quot; packages as dependencies</source>
         <translation>Apt asentaa ylimääräisiä &quot;suositeltuja&quot; paketteja riippuvuuksina</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1511"/>
+        <location filename="../tweak.ui" line="1576"/>
         <source>Generate fluxbox All Apps menu after package installation, removal, and updates</source>
         <translation>Luo fluxbox &quot;Kaikki sovellukset&quot; valikko asennuksen, poiston ja päivitysten jälkeen</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1518"/>
+        <location filename="../tweak.ui" line="1609"/>
         <source>Use Client Side Decorations (CSD) on GTK3 applications that support them (requires session restart)</source>
         <translation>Käytä koristeita (CSD) niitä tukevissa GTK3-sovelluksissa (edellyttää istunnon käynnistämistä uudelleen)</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1525"/>
+        <location filename="../tweak.ui" line="1508"/>
         <source>put a hold or remove a hold on updates of Liquorix kernels</source>
         <extracomment>toggle for apt hold action on update meta packages</extracomment>
         <translation>aseta tai poista lykkäys Liquorix kerneli päivityksille</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1528"/>
+        <location filename="../tweak.ui" line="1511"/>
         <source>Enable Automatic Liquorix Kernel Updates (MX ahs repository)</source>
         <extracomment>uses apt-mark to hold or unhold updates to kernel metapackages</extracomment>
         <translation>Ota käyttöön automaattiset Liquorix kerneli päivitykset (MX ahs arkisto)</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1535"/>
+        <location filename="../tweak.ui" line="1684"/>
         <source>put a hold or remove a hold on updates of Debian  kernels</source>
         <extracomment>toggle for apt hold action on update meta packages</extracomment>
         <translation>aseta tai poista lykkäys Debian kerneli päivityksille</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1538"/>
+        <location filename="../tweak.ui" line="1687"/>
         <source>Enable Automatic Debian Kernel Updates</source>
         <extracomment>uses apt-mark to hold or unhold updates to kernel metapackages</extracomment>
         <translation>Ota käyttöön automaattiset Debian kerneli päivitykset</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1545"/>
+        <location filename="../tweak.ui" line="1637"/>
         <source>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</source>
         <translation>Käytä Intel:in ajuria vakiollisen &quot;modesetting&quot; ajurin sijaan (vaatii uudelleenkäynnistyksen)</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1571"/>
+        <location filename="../tweak.ui" line="1471"/>
         <source>NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
         <translation>Huomaa: olemassa oleva /etc/X11/xorg.conf.d/20-intel.conf varmuuskopioidaan kotikansioon.</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1578"/>
+        <location filename="../tweak.ui" line="1583"/>
         <source>Use tearfree amdgpu option</source>
         <translation>Käytä repeytymätöntä amdgpu-vaihtoehtoa</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1585"/>
+        <location filename="../tweak.ui" line="1545"/>
         <source>NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
         <translation>Huomaa: olemassa oleva /etc/X11/xorg.conf.d/20-amd.conf varmuuskopioidaan kotikansioon.</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1592"/>
+        <location filename="../tweak.ui" line="1525"/>
         <source>Use tearfree radeon driver option</source>
         <translation>Käytä repeytymätöntä radeon-ajuri vaihtoehtoa</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1599"/>
+        <location filename="../tweak.ui" line="1501"/>
         <source>NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
         <translation>Huomaa: olemassa oleva /etc/X11/xorg.conf.d/20-radeon.conf varmuuskopioidaan kotikansioon.</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1606"/>
+        <location filename="../tweak.ui" line="1559"/>
         <source>Change computer name (requires reboot)</source>
         <extracomment>option to change the system hostname, requires a reboot to be 100% effective</extracomment>
         <translation>Vaihda tietokoneen nimi (vaatii käynnistyksen)</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1616"/>
+        <location filename="../tweak.ui" line="1552"/>
         <source>Change Default Display Manager (login screen) (requires reboot)</source>
         <extracomment>option to change display manager login screen.  present if more than one display manager is installed</extracomment>
         <translation>Muuta oletus näytönhallintaa (kirjautumisnäyttöä) (vaatii käynnistämisen)</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1629"/>
+        <location filename="../tweak.ui" line="1647"/>
         <source>Password for administrative tasks:</source>
         <translation>Salasana järjestelmänvalvojan tehtäviin:</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1636"/>
+        <location filename="../tweak.ui" line="1654"/>
         <source>&amp;User</source>
         <translation>&amp;Käyttäjä</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1643"/>
+        <location filename="../tweak.ui" line="1661"/>
         <source>Root</source>
         <translation>Root</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1693"/>
+        <location filename="../tweak.ui" line="1701"/>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Init system that is used as the default on the main grub boot menu entry&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../tweak.ui" line="1704"/>
+        <source>Change Default Init System</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../tweak.ui" line="1729"/>
         <source>Xfce Settings</source>
         <translation>Xfce:n asetukset</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1699"/>
+        <location filename="../tweak.ui" line="1735"/>
         <source>Customize the panel</source>
         <translation>Mukauta paneelia</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1709"/>
+        <location filename="../tweak.ui" line="1745"/>
         <source>Panel</source>
         <translation>Paneeli</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1729"/>
+        <location filename="../tweak.ui" line="1765"/>
         <source>Configure window behavior and shortcuts</source>
         <translation>Määritä ikkunan toiminta ja pikanäppäimet</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1762"/>
+        <location filename="../tweak.ui" line="1798"/>
         <source>Customize the look of your desktop</source>
         <translation>Mukauta työpöydän ulkoasua</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1775"/>
+        <location filename="../tweak.ui" line="1811"/>
         <source>Appearance</source>
         <translation>Ulkoasu</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1787"/>
+        <location filename="../tweak.ui" line="1823"/>
         <source>About</source>
         <translation>Tietoja</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1797"/>
+        <location filename="../tweak.ui" line="1833"/>
         <source>Help</source>
         <translation>Ohje</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1855"/>
+        <location filename="../tweak.ui" line="1891"/>
         <source>Quit application</source>
         <translation>Lopeta sovellus</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1858"/>
+        <location filename="../tweak.ui" line="1894"/>
         <source>Close</source>
         <translation>Sulje</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1864"/>
+        <location filename="../tweak.ui" line="1900"/>
         <source>Alt+N</source>
         <translation>Alt+N</translation>
     </message>
@@ -903,13 +913,13 @@
 <context>
     <name>TweakMisc</name>
     <message>
-        <location filename="../tweak_misc.cpp" line="289"/>
+        <location filename="../tweak_misc.cpp" line="305"/>
         <source>Please enter a computer name.</source>
         <comment>question to enter a name for the computer hostname</comment>
         <translation>Syötä nimi tietokoneelle. </translation>
     </message>
     <message>
-        <location filename="../tweak_misc.cpp" line="293"/>
+        <location filename="../tweak_misc.cpp" line="309"/>
         <source>Sorry, your computer name contains invalid characters.
 You'll have to select a different
 name before proceeding.</source>
