@@ -71,15 +71,15 @@
     <message>
         <location filename="../tweak.ui" line="39"/>
         <location filename="../tweak.ui" line="233"/>
-        <location filename="../tweak.ui" line="508"/>
-        <location filename="../tweak.ui" line="587"/>
-        <location filename="../tweak.ui" line="643"/>
-        <location filename="../tweak.ui" line="670"/>
-        <location filename="../tweak.ui" line="862"/>
-        <location filename="../tweak.ui" line="1253"/>
-        <location filename="../tweak.ui" line="1382"/>
-        <location filename="../tweak.ui" line="1429"/>
-        <location filename="../tweak.ui" line="1679"/>
+        <location filename="../tweak.ui" line="520"/>
+        <location filename="../tweak.ui" line="599"/>
+        <location filename="../tweak.ui" line="655"/>
+        <location filename="../tweak.ui" line="682"/>
+        <location filename="../tweak.ui" line="874"/>
+        <location filename="../tweak.ui" line="1265"/>
+        <location filename="../tweak.ui" line="1394"/>
+        <location filename="../tweak.ui" line="1441"/>
+        <location filename="../tweak.ui" line="1532"/>
         <source>Apply</source>
         <extracomment>apply changes</extracomment>
         <translation>Uygula</translation>
@@ -116,9 +116,9 @@
     </message>
     <message>
         <location filename="../tweak.ui" line="101"/>
-        <location filename="../tweak.ui" line="1036"/>
-        <location filename="../tweak.ui" line="1146"/>
-        <location filename="../tweak.ui" line="1273"/>
+        <location filename="../tweak.ui" line="1048"/>
+        <location filename="../tweak.ui" line="1158"/>
+        <location filename="../tweak.ui" line="1285"/>
         <source>Placement</source>
         <translation>Yerleştirme</translation>
     </message>
@@ -186,663 +186,673 @@
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="295"/>
+        <location filename="../tweak.ui" line="301"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Toggle Dark Mode for GTK4 libadwaita applications&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="298"/>
+        <location filename="../tweak.ui" line="304"/>
         <source>Dark Mode</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="305"/>
-        <location filename="../tweak.ui" line="1742"/>
+        <location filename="../tweak.ui" line="311"/>
+        <location filename="../tweak.ui" line="1778"/>
         <source>Window Manager</source>
         <extracomment>theme a window manager border will get</extracomment>
         <translation>Pencere Yöneticisi</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="319"/>
+        <location filename="../tweak.ui" line="331"/>
         <source>Legacy Styles</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="332"/>
+        <location filename="../tweak.ui" line="344"/>
         <source>Icons</source>
         <extracomment>icon theme</extracomment>
         <translation>Simgeler</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="339"/>
+        <location filename="../tweak.ui" line="351"/>
         <source>Cursors</source>
         <extracomment>cursor theme</extracomment>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="346"/>
+        <location filename="../tweak.ui" line="358"/>
         <source>Save Current Settings as a Theme Set</source>
         <extracomment>save theme settings as a group</extracomment>
         <translation>Mevcut Ayarları Tema Ayarı Olarak Kaydet</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="356"/>
+        <location filename="../tweak.ui" line="368"/>
         <source>Size</source>
         <extracomment>size of the cursor</extracomment>
         <translation>Boyut</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="366"/>
+        <location filename="../tweak.ui" line="378"/>
         <source>default</source>
         <extracomment>default cursor size determined by X server</extracomment>
         <translation>öntanımlı</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="389"/>
-        <location filename="../tweak.ui" line="441"/>
+        <location filename="../tweak.ui" line="401"/>
+        <location filename="../tweak.ui" line="453"/>
         <source>Compositor</source>
         <translation>Compositor</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="401"/>
+        <location filename="../tweak.ui" line="413"/>
         <source>Changing the VBlank mode may help alleviate some screen tearing issues. See Help for more information.</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="404"/>
+        <location filename="../tweak.ui" line="416"/>
         <source>VBlank</source>
         <translation>VBlank</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="412"/>
+        <location filename="../tweak.ui" line="424"/>
         <source>auto</source>
         <translation>oto</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="417"/>
+        <location filename="../tweak.ui" line="429"/>
         <source>glx</source>
         <translation>glx</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="422"/>
+        <location filename="../tweak.ui" line="434"/>
         <source>xpresent</source>
         <translation>xpresent</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="427"/>
-        <location filename="../tweak.ui" line="1010"/>
+        <location filename="../tweak.ui" line="439"/>
+        <location filename="../tweak.ui" line="1022"/>
         <source>off</source>
         <extracomment>setting to 0 turns off screensaver screen blank</extracomment>
         <translation>kapalı</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="435"/>
+        <location filename="../tweak.ui" line="447"/>
         <source>Transparency and shadow options</source>
         <translation>Saydamlık ve gölge seçenekleri</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="451"/>
+        <location filename="../tweak.ui" line="463"/>
         <source>Xfce Compositor Settings</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="454"/>
+        <location filename="../tweak.ui" line="466"/>
         <source>Xfwm Settings</source>
         <translation>Xfwm Ayarları</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="464"/>
+        <location filename="../tweak.ui" line="476"/>
         <source>Launch compton-conf configuration tool</source>
         <translation>compton-conf yapılandırma aracını başlat</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="467"/>
+        <location filename="../tweak.ui" line="479"/>
         <source>Picom settings</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="478"/>
+        <location filename="../tweak.ui" line="490"/>
         <source>Edit compton.conf directly in text editor</source>
         <translation>compton.conf dosyasını doğrudan metin düzenleyicide düzenleyin</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="481"/>
+        <location filename="../tweak.ui" line="493"/>
         <source>Edit picom.conf</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="528"/>
+        <location filename="../tweak.ui" line="540"/>
         <source>Display</source>
         <translation>Görüntü</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="534"/>
+        <location filename="../tweak.ui" line="546"/>
         <source>Display Tweaks</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="540"/>
+        <location filename="../tweak.ui" line="552"/>
         <source>Hardware Backlight</source>
         <extracomment>set the hardware backlight on monitors that have them</extracomment>
         <translation>Donanım Arka Işığı</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="563"/>
-        <location filename="../tweak.ui" line="694"/>
+        <location filename="../tweak.ui" line="575"/>
+        <location filename="../tweak.ui" line="706"/>
         <source>TextLabel</source>
         <translation>Metin Etiketi</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="570"/>
+        <location filename="../tweak.ui" line="582"/>
         <source>GTK scaling</source>
         <extracomment>gtk scale factor</extracomment>
         <translation>GTK ölçeği</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="623"/>
+        <location filename="../tweak.ui" line="635"/>
         <source>Choose Display for xrandr tweaks</source>
         <extracomment>choose the display that the xrandr tweaks will be acted upon</extracomment>
         <translation>Xrandr ince ayarları için Görüntüleme Seçimi</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="633"/>
+        <location filename="../tweak.ui" line="645"/>
         <source>Resolution</source>
         <translation>Çözünürlük</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="650"/>
+        <location filename="../tweak.ui" line="662"/>
         <source>xrandr Scaling</source>
         <extracomment>xrandr scale factor</extracomment>
         <translation>xrandr Ölçekleme</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="677"/>
+        <location filename="../tweak.ui" line="689"/>
         <source>Software (xrandr) Brightness</source>
         <extracomment>adjust brightness (not backlight) via software</extracomment>
         <translation>Yazılım (xrandr) Parlaklığı</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="701"/>
+        <location filename="../tweak.ui" line="713"/>
         <source>Saving is per display</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="704"/>
+        <location filename="../tweak.ui" line="716"/>
         <source>Save</source>
         <translation>Kaydet</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="728"/>
+        <location filename="../tweak.ui" line="740"/>
         <source>Xfce</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="734"/>
+        <location filename="../tweak.ui" line="746"/>
         <source>Desktop</source>
         <translation>Masaüstü</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="740"/>
+        <location filename="../tweak.ui" line="752"/>
         <source>Enable single-click on desktop</source>
         <translation>Masaüstünde tek tık etkin</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="747"/>
+        <location filename="../tweak.ui" line="759"/>
         <source>Enable Desktop Zoom </source>
         <translation>Masaüstü Yakınlaştırmayı Etkinleştir </translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="754"/>
-        <location filename="../tweak.ui" line="1343"/>
+        <location filename="../tweak.ui" line="766"/>
+        <location filename="../tweak.ui" line="1355"/>
         <source>Show windows from all workspaces in panel</source>
         <translation>Tüm çalışma alanlarındaki pencereleri panelde göster.</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="761"/>
+        <location filename="../tweak.ui" line="773"/>
         <source>Do not shorten file names on the desktop</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="771"/>
+        <location filename="../tweak.ui" line="783"/>
         <source>Thunar</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="777"/>
+        <location filename="../tweak.ui" line="789"/>
         <source>Enable single-click in Thunar File Manager</source>
         <translation>Thunar Dosya Yöneticisinde tek tık etkin</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="784"/>
+        <location filename="../tweak.ui" line="796"/>
         <source>Reset custom right-click actions to system defaults</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="791"/>
+        <location filename="../tweak.ui" line="803"/>
         <source>Thunar windows always open in split view</source>
         <translation>Thunar pencereleri her zaman bölünmüş görünümde açılır</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="798"/>
+        <location filename="../tweak.ui" line="810"/>
         <source>Thunar split view opens horizontal</source>
         <translation>Thunar bölünmüş görünüm yatay açılır</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="808"/>
+        <location filename="../tweak.ui" line="820"/>
         <source>Show percentages in notifcations when available</source>
         <translation>Mevcut ise bildirimlerde yüzdeleri göster</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="815"/>
+        <location filename="../tweak.ui" line="827"/>
         <source>Show GTK File Dialog action buttons at bottom of dialogs</source>
         <translation>İletişim kutularının altında GTK Dosya İletişim Kutusu eylem düğmelerini göster</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="822"/>
+        <location filename="../tweak.ui" line="834"/>
         <source>(also turns off Client Side Decorations for Xfce applications)</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="832"/>
+        <location filename="../tweak.ui" line="844"/>
         <source>Enable hibernate on Log Out menu </source>
         <translation>Oturumu Kapat menüsünde hazırda bekletme kipini etkinleştir</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="839"/>
+        <location filename="../tweak.ui" line="851"/>
         <source>note: to hibernate, swap needs to be &gt;= RAM</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="873"/>
+        <location filename="../tweak.ui" line="885"/>
         <source>Fluxbox</source>
         <translation>Fluxbox</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="879"/>
-        <location filename="../tweak.ui" line="1353"/>
+        <location filename="../tweak.ui" line="891"/>
+        <location filename="../tweak.ui" line="1365"/>
         <source>Reset Defaults</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="885"/>
+        <location filename="../tweak.ui" line="897"/>
         <source>Reset DefaultDock</source>
         <translation>Öntanımlı Sabitleyiciyi Sıfırla</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="892"/>
+        <location filename="../tweak.ui" line="904"/>
         <source>Reset Fluxbox Menu</source>
         <translation>Fluxbox Menüyü Sıfırla</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="899"/>
+        <location filename="../tweak.ui" line="911"/>
         <source>Reset ALL mx-fluxbox settings</source>
         <translation>TÜM mx-fluxbox ayarlarını sıfırla</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="906"/>
+        <location filename="../tweak.ui" line="918"/>
         <source>Add new default menu items, if any, to existing fluxbox menu.</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="909"/>
+        <location filename="../tweak.ui" line="921"/>
         <source>Upgrade existing menu entries</source>
         <translation>Mevcut menü girişlerini güncelle</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="919"/>
+        <location filename="../tweak.ui" line="931"/>
         <source>Desktop Icons</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="925"/>
+        <location filename="../tweak.ui" line="937"/>
         <source>Toggle desktop icons</source>
         <translation>Masaüstü simgelerini değiştir</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="933"/>
-        <location filename="../tweak.ui" line="957"/>
+        <location filename="../tweak.ui" line="945"/>
+        <location filename="../tweak.ui" line="969"/>
         <source>On</source>
         <translation>Aç</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="938"/>
-        <location filename="../tweak.ui" line="962"/>
+        <location filename="../tweak.ui" line="950"/>
+        <location filename="../tweak.ui" line="974"/>
         <source>Off</source>
         <translation>Kapat</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="946"/>
+        <location filename="../tweak.ui" line="958"/>
         <source>Toggle icon captions</source>
         <translation>Simge altyazılarını değiştir</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="967"/>
+        <location filename="../tweak.ui" line="979"/>
         <source>On Hover</source>
         <translation>Vurgulu</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="994"/>
+        <location filename="../tweak.ui" line="1006"/>
         <source>Screensaver</source>
         <translation>Ekran Koruyucu</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1000"/>
+        <location filename="../tweak.ui" line="1012"/>
         <source>Idle time (minutes)</source>
         <extracomment>set the time of inactivity  before screensaver screen blank occurs</extracomment>
         <translation>Boşta zaman (dakika)</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1023"/>
+        <location filename="../tweak.ui" line="1035"/>
         <source>Toolbar Settings</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1029"/>
+        <location filename="../tweak.ui" line="1041"/>
         <source>Height</source>
         <translation>Yükseklik</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1110"/>
-        <location filename="../tweak.ui" line="1220"/>
+        <location filename="../tweak.ui" line="1122"/>
+        <location filename="../tweak.ui" line="1232"/>
         <source>Autohide</source>
         <translation>Otomatik gizleme</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1117"/>
+        <location filename="../tweak.ui" line="1129"/>
         <source>Show Toolbar</source>
         <translation>Araç Çubuğunu Göster</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1124"/>
+        <location filename="../tweak.ui" line="1136"/>
         <source>Width</source>
         <translation>Genişlik</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1140"/>
+        <location filename="../tweak.ui" line="1152"/>
         <source>Dock Settings</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1227"/>
+        <location filename="../tweak.ui" line="1239"/>
         <source>Manage Tint2 Panel</source>
         <translation>Tint2 Panelini Yönet</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1261"/>
+        <location filename="../tweak.ui" line="1273"/>
         <source>Plasma</source>
         <translation>Plasma</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1267"/>
+        <location filename="../tweak.ui" line="1279"/>
         <source>Affects 1st panel</source>
         <translation>1. paneli etkiler</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1284"/>
+        <location filename="../tweak.ui" line="1296"/>
         <source>Bottom</source>
         <translation>En alt</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1289"/>
+        <location filename="../tweak.ui" line="1301"/>
         <source>Left</source>
         <translation>Sol</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1294"/>
+        <location filename="../tweak.ui" line="1306"/>
         <source>Top</source>
         <translation>En üst</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1299"/>
+        <location filename="../tweak.ui" line="1311"/>
         <source>Right</source>
         <translation>Sağ</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1323"/>
+        <location filename="../tweak.ui" line="1335"/>
         <source>Workspace</source>
         <translation>Çalışma Alanı</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1329"/>
+        <location filename="../tweak.ui" line="1341"/>
         <source>Autostart plasma-discover system tray update notification utility</source>
         <extracomment>enable or disable autostartup of plasma-discover updater utility on login</extracomment>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1336"/>
+        <location filename="../tweak.ui" line="1348"/>
         <source>Enable single-click</source>
         <translation>Tek tıklamayı etkinleştir</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1359"/>
+        <location filename="../tweak.ui" line="1371"/>
         <source>Reset KDE/Plasma defaults</source>
         <translation>KDE/Plasma öntanımlılarını sıfırla</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1393"/>
+        <location filename="../tweak.ui" line="1405"/>
         <source>Super Key</source>
         <extracomment>referring to the meta or Left Super Key</extracomment>
         <translation>Super Tuşu</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1399"/>
+        <location filename="../tweak.ui" line="1411"/>
         <source>Also known as the &quot;windows&quot; key</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1402"/>
+        <location filename="../tweak.ui" line="1414"/>
         <source>Command to run with Super (Meta) key</source>
         <extracomment>label for the field to enter the command to use with super key</extracomment>
         <translation>Süper (Meta) tuşuyla çalıştırılacak komut</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1412"/>
+        <location filename="../tweak.ui" line="1424"/>
         <source>xfce-superkey defaults</source>
         <extracomment>indicates that xfce-superkey will select a command by its default logic</extracomment>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1419"/>
+        <location filename="../tweak.ui" line="1431"/>
         <source>Choose application</source>
         <extracomment>description of button action to launch file dialog to choose an application</extracomment>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1450"/>
+        <location filename="../tweak.ui" line="1462"/>
         <source>Miscellaneous</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1456"/>
+        <location filename="../tweak.ui" line="1518"/>
         <source>Reset Lightdm (login screen) to system default theme</source>
         <translation>Lightdm’yi (giriş ekranı) sistem öntanımlı temasına sıfırla</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1463"/>
+        <location filename="../tweak.ui" line="1623"/>
         <source>Enable mounting of internal drives by non-root users</source>
         <translation>Dahili sürücülerin root olmayan kullanıcılar tarafından bağlanmasını etkinleştir</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1470"/>
+        <location filename="../tweak.ui" line="1616"/>
         <source>Enable kernel sandbox</source>
         <translation>Çekirdek sanal alanını etkinleştir</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1477"/>
+        <location filename="../tweak.ui" line="1566"/>
         <source>requires reboot</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1480"/>
+        <location filename="../tweak.ui" line="1569"/>
         <source>Enable Bluetooth adapters on boot</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1487"/>
+        <location filename="../tweak.ui" line="1694"/>
         <source>Enable Bluetooth battery info for connected devices (requires system restart)</source>
         <extracomment>expose battery info for connected bluetooth devices to the operating system via dbus</extracomment>
         <translation>Bağlı aygıtların pil bilgileri için Bluetooth&apos;u etkinleştir (sistemin yeniden başlatılmasını gerektirir)</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1494"/>
+        <location filename="../tweak.ui" line="1491"/>
         <source>Early loading of KVM module is new to  kernel 6.12 and conflicts with some non-KVM virtual machine applications, including virtualbox</source>
         <extracomment>early loading is new on 6.12 kernel and conflicts with virtualbox</extracomment>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1497"/>
+        <location filename="../tweak.ui" line="1494"/>
         <source>Disable early KVM module load (must be disabled for Virtualbox operation on kernel 6.12 and up)</source>
         <extracomment>disable early loading of KVM module.  necessary for virtualbox to function with kernels 6.12 and up.  actually default behavior on kernels 6.11 and earlier.</extracomment>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1504"/>
+        <location filename="../tweak.ui" line="1630"/>
         <source>Apt installs additional &quot;recommends&quot; packages as dependencies</source>
         <translation>Apt, bağımlılık olarak &quot;önerilen&quot; ek paketleri kurar</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1511"/>
+        <location filename="../tweak.ui" line="1576"/>
         <source>Generate fluxbox All Apps menu after package installation, removal, and updates</source>
         <translation>Paket yükleme, kaldırma ve güncellemelerden sonra fluxbox Tüm Uygulamalar menüsünu oluşturur</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1518"/>
+        <location filename="../tweak.ui" line="1609"/>
         <source>Use Client Side Decorations (CSD) on GTK3 applications that support them (requires session restart)</source>
         <translation>Onları destekleyen GTK3 uygulamalarında İstemci Tarafı Dekorasyonlarını (CSD) kullanın (oturumun yeniden başlatılmasını gerektirir)</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1525"/>
+        <location filename="../tweak.ui" line="1508"/>
         <source>put a hold or remove a hold on updates of Liquorix kernels</source>
         <extracomment>toggle for apt hold action on update meta packages</extracomment>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1528"/>
+        <location filename="../tweak.ui" line="1511"/>
         <source>Enable Automatic Liquorix Kernel Updates (MX ahs repository)</source>
         <extracomment>uses apt-mark to hold or unhold updates to kernel metapackages</extracomment>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1535"/>
+        <location filename="../tweak.ui" line="1684"/>
         <source>put a hold or remove a hold on updates of Debian  kernels</source>
         <extracomment>toggle for apt hold action on update meta packages</extracomment>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1538"/>
+        <location filename="../tweak.ui" line="1687"/>
         <source>Enable Automatic Debian Kernel Updates</source>
         <extracomment>uses apt-mark to hold or unhold updates to kernel metapackages</extracomment>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1545"/>
+        <location filename="../tweak.ui" line="1637"/>
         <source>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</source>
         <translation>Öntanımlı &quot;modesetting&quot; sürücü yerine intel sürücüsü kullanın (yeniden başlatma gerekir)</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1571"/>
+        <location filename="../tweak.ui" line="1471"/>
         <source>NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1578"/>
+        <location filename="../tweak.ui" line="1583"/>
         <source>Use tearfree amdgpu option</source>
         <translation>Amd  grafik işlemcinin tearfree seçeneğini kullan</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1585"/>
+        <location filename="../tweak.ui" line="1545"/>
         <source>NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1592"/>
+        <location filename="../tweak.ui" line="1525"/>
         <source>Use tearfree radeon driver option</source>
         <translation>tearfree radeon sürücü seçeneğini kullan</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1599"/>
+        <location filename="../tweak.ui" line="1501"/>
         <source>NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1606"/>
+        <location filename="../tweak.ui" line="1559"/>
         <source>Change computer name (requires reboot)</source>
         <extracomment>option to change the system hostname, requires a reboot to be 100% effective</extracomment>
         <translation>Bilgisayar adını değiştir (yeniden başlatma gerektirir)</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1616"/>
+        <location filename="../tweak.ui" line="1552"/>
         <source>Change Default Display Manager (login screen) (requires reboot)</source>
         <extracomment>option to change display manager login screen.  present if more than one display manager is installed</extracomment>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1629"/>
+        <location filename="../tweak.ui" line="1647"/>
         <source>Password for administrative tasks:</source>
         <translation>Yönetici görevleri için parola:</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1636"/>
+        <location filename="../tweak.ui" line="1654"/>
         <source>&amp;User</source>
         <translation>Kullanıcı</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1643"/>
+        <location filename="../tweak.ui" line="1661"/>
         <source>Root</source>
         <translation>Kök</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1693"/>
+        <location filename="../tweak.ui" line="1701"/>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Init system that is used as the default on the main grub boot menu entry&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../tweak.ui" line="1704"/>
+        <source>Change Default Init System</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../tweak.ui" line="1729"/>
         <source>Xfce Settings</source>
         <translation>Xfce Ayarları</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1699"/>
+        <location filename="../tweak.ui" line="1735"/>
         <source>Customize the panel</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1709"/>
+        <location filename="../tweak.ui" line="1745"/>
         <source>Panel</source>
         <translation>Panel</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1729"/>
+        <location filename="../tweak.ui" line="1765"/>
         <source>Configure window behavior and shortcuts</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1762"/>
+        <location filename="../tweak.ui" line="1798"/>
         <source>Customize the look of your desktop</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1775"/>
+        <location filename="../tweak.ui" line="1811"/>
         <source>Appearance</source>
         <translation>Görünüm</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1787"/>
+        <location filename="../tweak.ui" line="1823"/>
         <source>About</source>
         <translation>Hakkında</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1797"/>
+        <location filename="../tweak.ui" line="1833"/>
         <source>Help</source>
         <translation>Yardım</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1855"/>
+        <location filename="../tweak.ui" line="1891"/>
         <source>Quit application</source>
         <translation>Uygulamadan çık</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1858"/>
+        <location filename="../tweak.ui" line="1894"/>
         <source>Close</source>
         <translation>Kapat</translation>
     </message>
     <message>
-        <location filename="../tweak.ui" line="1864"/>
+        <location filename="../tweak.ui" line="1900"/>
         <source>Alt+N</source>
         <translation>Alt+N</translation>
     </message>
@@ -903,13 +913,13 @@
 <context>
     <name>TweakMisc</name>
     <message>
-        <location filename="../tweak_misc.cpp" line="289"/>
+        <location filename="../tweak_misc.cpp" line="305"/>
         <source>Please enter a computer name.</source>
         <comment>question to enter a name for the computer hostname</comment>
         <translation>Lütfen bir bilgisayar adı girin.</translation>
     </message>
     <message>
-        <location filename="../tweak_misc.cpp" line="293"/>
+        <location filename="../tweak_misc.cpp" line="309"/>
         <source>Sorry, your computer name contains invalid characters.
 You'll have to select a different
 name before proceeding.</source>
